﻿var PesquisarEstoqueController = ControllerBase.extend({
    ajax: function () {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            Codigo: this.model.get('CodigoProduto'),
            RetornaTodasAsFiliais: true
        };

        return {
            url: '/Produto/_Estoque',
            type: 'post',
            cache: false,
            contentType: 'application/json',
            data: JSON.stringify({
                pesquisa: pesquisa
            })
        };
    },


    renderizado: function () {

        $("#menu-sub-consulta-produtos").show();

        $("#reserva-item-menu").unbind();
        $("#reserva-item-menu").click($.proxy(this.pesquisarReservas, this));

        $("#pedido-cliente-item-menu").unbind();
        $("#pedido-cliente-item-menu").click($.proxy(this.pesquisarPedidoCliente, this));

        $("#pedido-fornecedor-item-menu").unbind();
        $("#pedido-fornecedor-item-menu").click($.proxy(this.pesquisarPedidoFornecedor, this));        

        this.EstoqueProdutoView = this.showView({
            region: {
                name: 'estoqueProdutoViewRegion',
                selector: '#pesquisar-estoque-produto-region'
            },
            view: {
                type: EstoqueProdutoView,
                args: {
                    model: this.model,
                    collection: new Estoques(this.collection)
                }
            }
        });

        this.atualizarTotais();

    },


    atualizarTotais: function () {
        
        
        $('#total-quantidade').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.Quantidade }, 0)));
        $('#total-reservado').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QuantidadeReservado }, 0)));
        $('#total-disponivel').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QuantidadeDisponivel }, 0)));
        $('#total-transito').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QuantidadeEmTransito }, 0)));
        $('#total-pedido-fornecedor').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.PedidosFornecedor }, 0)));
        $('#total-nao-entregue-expedicao').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QtdeNaoEntregueExpedicao }, 0)));
        $('#total-nao-entregue-futura').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QuantidadeNaoEntregueFutura }, 0)));
        $('#total-disponivel-lote').html(global.formatNumber(this.collection.reduce(function (memo, value) { return memo + value.QuantidadeDisponivelLote }, 0)));
    },

    pesquisarReservas: function () {

        if (!this.model) {
            global.showErrorMessage('Selecione um produto antes de consultar as reservas.');
            return;
        }

        this.pesquisarReservaController = this.showView({
            region: {
                name: 'pesquisarReservaControllerRegion',
                selector: '#pesquisar-reserva-produto-container'
            },
            controller: {
                type: PesquisarReservaController,
                args: {
                    model: this.model,
                    produto: this.EstoqueProdutoView.model.get('CodigoProduto') + ' - ' + this.EstoqueProdutoView.model.get('DescricaoProduto')
                }
            }

        });
    },

    pesquisarPedidoCliente: function () {

        if (!this.model) {
            global.showErrorMessage('Selecione um produto antes de consultar os pedidos de clientes.');
            return;
        }

        this.pedidoClienteController = this.showView({
            region: {
                name: 'pedidoClienteControllerRegion',
                selector: '#pesquisar-pedido-cliente-container'
            },
            controller: {
                type: PedidoClienteController,
                args: {
                    model: this.model,
                    produto: this.EstoqueProdutoView.model.get('CodigoProduto') + ' - ' + this.EstoqueProdutoView.model.get('DescricaoProduto')
                }
            }

        });
    },

    pesquisarPedidoFornecedor: function () {

        if (!this.model) {
            global.showErrorMessage('Selecione um produto antes de consultar os pedidos de fornecedores.');
            return;
        }

        this.pedidoFornecedorController = this.showView({
            region: {
                name: 'pedidoFornecedorControllerRegion',
                selector: '#pesquisar-pedido-fornecedor-container'
            },
            controller: {
                type: PedidoFornecedorController,
                args: {
                    model: this.model,
                    produto: this.EstoqueProdutoView.model.get('CodigoProduto') + ' - ' + this.EstoqueProdutoView.model.get('DescricaoProduto')
                }
            }

        });
    },

    onhide: function (item) {        
        $("#menu-sub-consulta-produtos").hide();
    }    
});