﻿var PesquisarProdutosController = ControllerBase.extend({
    initialize: function () {
        this.menuConsultaProdutosController = new MenuConsultaProdutosController({
            controller: this,
            adicionarProdutosCallback: $.proxy(this.adicionarProdutos, this)
        });
    },

    form: '#form-pesquisar-produto',

    ajax: function () {

        return {
            url: '/Produto/_Pesquisar',
            type: 'get',
            cache: false
        };
    },

    renderizado: function () {

        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();

        this.atacharEventos();
        this.configurarForm();

        this.obterParametroFocus(false);

    },

    atacharEventos: function () {

        $('#pesquisar-produtos').click($.proxy(this.pesquisarClick, this));
        $('#pesquisar-fornecedores').click($.proxy(this.pesquisarFornecedores, this));
        $('#pesquisar-classes-produtos').click($.proxy(this.pesquisarClasses, this));
        $('#remover-classe-produto').click($.proxy(this.removerClasse, this));
        $('#remover-fornecedor').click($.proxy(this.removerFornecedor, this));
        $('#mostrar-mais-filtros').click($.proxy(this.mostrarMaisFiltros, this));

        this.addActionButton({
            id: 'mostrar-historico-filtro',
            text: 'Pesquisas anteriores',
            'class': 'icone-pesquisar',
            click: $.proxy(this.pesquisarHistoricoFiltro, this)
        }, true);
    },

    mostrarMaisFiltros: function (e) {
        $('#mostrar-mais-filtros').toggleClass("oculto");
        e.preventDefault();

        var $filtros = $('#mais-filtros');

        if ($filtros.is(':visible')) {
            $filtros.slideUp(200);
        } else {
            $filtros.slideDown(200);
        }

    },

    configurarForm: function () {

        var self = this;

        this.validationOptions = {
            errorClass: 'obrigatorio',
            onkeyup: false,
            errorPlacement: function (error, element) {
                return true;
            },
            focusInvalid: false,
            invalidHandler: function (event, validator) {

                var errors = validator.numberOfInvalids();

                if (errors) {
                    var messages = new Array();

                    $.each(validator.errorList, function () {
                        messages.push(this.message);
                    });

                    global.showErrorMessage(messages);

                    return false;
                }

            }
        };

        $(this.form).validate(this.validationOptions);

        this.obterParametrosFiltro(true);
    },

    obterParametroFocus: function (async) {
        this.obterParamentro('CHAVE_MOVIMENTACAO', async);
    },

    obterParametrosFiltro: function (async) {
        this.obterParamentro('UTILIZA_SISTEMA_TINTOMETRICO', async);
        this.obterParamentro('PRODUTO_EM_TRANSITO', async);
    },

    obterParametrosInfo: function (async) {
        this.obterParamentro('EXIBIR_PRECO_COMISSAO_NA_CONSULTA_PRODUTOS', async);
        this.obterParamentro('EXIBIR_QUANTIDADE_MINIMA_VENDA_CONSULTA_PRODUTOS', async);
    },

    obterParamentro: function (nomeInterno, async) {

        var pesquisa = {
            nomeInterno: nomeInterno
        };

        var self = this;

        global.ajax({
            url: '/Usuario/_ObterParametro',
            type: "post",
            contentType: 'application/json',
            data: JSON.stringify(pesquisa),
            async: async,
            success: function (data) {
                self.acaoParametro(pesquisa.nomeInterno, data);
            }
        });
    },

    acaoParametro: function (nomeInterno, valorParametro) {

        switch (nomeInterno) {
            case 'UTILIZA_SISTEMA_TINTOMETRICO':
                /* REMOVIDO TEMPORARIAMENTE ( SOLICITADO PELA MICROUNIVERSO )
                if (valorParametro != 'S') {
                    $('#linha-filtro-sistema-tintometrico').hide();
                    $('#linha-filtro-produto-final').hide();
                }*/
                $('#linha-filtro-sistema-tintometrico').remove();
                $('#linha-filtro-produto-final').remove();
                break;
            case 'PRODUTO_EM_TRANSITO':
                if (valorParametro != 'S') {
                    $('#linha-filtro-produto-transito').remove();
                } else {
                    $('#linha-filtro-produto-transito').show();
                }
                break;
            case 'EXIBIR_PRECO_COMISSAO_NA_CONSULTA_PRODUTOS':
                if (valorParametro != 'S')
                    $('#detalhes-produto-region').find('#linha-comissao-venda').remove();
                else
                    $('#detalhes-produto-region').find('#linha-comissao-venda').show();
                break;
            case 'EXIBIR_QUANTIDADE_MINIMA_VENDA_CONSULTA_PRODUTOS':
                if (valorParametro != 'S')
                    $('#detalhes-produto-region').find('#linha-quantidade-minima-venda').remove();
                else
                    $('#detalhes-produto-region').find('#linha-quantidade-minima-venda').show();
                break;
            case 'CHAVE_MOVIMENTACAO':
                if (valorParametro != 'C')
                    $('#Referencia').focus();
                else
                    $('#Codigo').focus();
                break;
        }
    },

    pesquisar: function (e, numeroPagina) {

        if (e) {
            e.preventDefault();
        }

        global.blockUI();

        var formdata = global.convertFormToJSON({ selector: this.form });
        formdata.TamanhoPagina = this.pesquisa && this.pesquisa.PageSize > 0 ? this.pesquisa.PageSize : 20;
        formdata.NumeroPagina = this.pesquisa && this.pesquisa.ActualPage > 0 ? this.pesquisa.ActualPage : 1;

        if (numeroPagina)
            formdata.NumeroPagina = numeroPagina;

        if (this.model.get('IdentificadorOrcamento'))
            formdata.identificadorOrcamento = this.model.get('IdentificadorOrcamento');

        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();

        var self = this;

        global.ajax({
            url: '/Produto/Pesquisar',
            type: "post",
            contentType: 'application/json',
            data: JSON.stringify(formdata),
            error: function () {
                global.unblockUI();
                global.showErrorMessage('Ocorreu um problema com a requisição, por favor tente novamente.');
            },
            success: function (data) {

                data = global.tratarRetorno(data);

                if (data == null)
                    $("#produtos-region").hide();
                else {
                    self.carregar(data);
                }
            }
        });
    },

    pesquisarFornecedores: function (e) {
        e.preventDefault();

        this.pesquisarFornecedoresController = this.showView({
            region: {
                name: 'pesquisarFornecedoresRegion',
                selector: '#pesquisar-fornecedores-region'
            },
            controller: {
                type: PesquisarFornecedoresController,
                args: {
                    fornecedorSelecionadoCallback: $.proxy(this.fornecedorSelecionado, this)
                }
            }

        });



    },

    pesquisarClasses: function (e) {
        e.preventDefault();

        this.pesquisarClassesProdutosController = this.showView({
            region: {
                name: 'pesquisarClassesProdutosRegion',
                selector: '#pesquisar-classes-produtos-region'
            },
            controller: {
                type: PesquisarClassesProdutosController,
                args: {
                    classeSelecionadaCallback: $.proxy(this.classeSelecionada, this)
                }
            }

        });

        $('#pesquisar-produtos-region').hide();

    },

    removerClasse: function (e) {
        e.preventDefault();
        $('[name=Classe]').val('');
        $('[name=ClasseProduto]').val('');
    },

    removerFornecedor: function (e) {
        e.preventDefault();
        $('[name=Fornecedor]').val('');
        $('[name=NomeFornecedor]').val('');
    },

    onhide: function (item) {
        $('#menu-consulta-produtos').hide();
        $("#menu-sub-consulta-produtos").hide();
    },

    pesquisarEstoque: function (e) {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 10,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            Codigo: "00826",
            RetornaTodasAsFiliais: true
        };

        this.pesquisarEstoqueItemController = this.showView({
            region: {
                name: 'estoqueProdutoRegion',
                selector: '#pesquisar-estoque-produto-container'
            },
            controller: {
                type: PesquisarEstoqueController,
                args: {
                    pesquisa: pesquisa,
                    model: this.model
                }
            }

        });

        $('#pesquisar-produtos-region').hide();

    },

    classeSelecionada: function (classe) {
        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();
        this.pesquisarClassesProdutosController.hide();
        $('#pesquisar-produtos-region').show();

        if (classe) {
            $('[name=Classe]').val(classe.ClasseProduto);
            $('[name=ClasseProduto]').val(classe.Nome);
        }

    },

    fornecedorSelecionado: function (fornecedor) {
        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();

        this.pesquisarFornecedoresController.hide();
        $('#pesquisar-produtos-region').show();

        if (fornecedor) {
            $('[name=Fornecedor]').val(fornecedor.get('CodigoInterno'));
            $('[name=NomeFornecedor]').val(fornecedor.get('Nome'));
        }
    },

    paginar: function (e) {
        this.pesquisa.ActualPage = e.page;
        this.pesquisar();
    },

    pesquisarClick: function (e) {

        if (e) {
            e.preventDefault();
        }

        this.pesquisar(e, 1); // Pesquisa sempre a primeira página.
    },

    carregar: function (data) {

        if (!data) {
            global.unblockUI();
            return;;
        }

        this.pesquisa = data;

        $('#produtos-region').removeClass('none').addClass('separador');
        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();

        this.produtosView = this.showView({
            region: {
                name: 'produtosRegion',
                selector: '#produtos-region'
            },
            view: {
                type: ProdutosView,
                args: {
                    collection: new Produtos(data.Entities),
                    adicionarProdutosCallback: this.adicionarProdutosCallback
                }
            }
        });

        this.paginador = new Paginator({
            container: '#pesquisar-produtos-page-container',
            data: data,
            pageClickCallback: $.proxy(this.paginar, this)
        });

        this.obterParametrosInfo(true);

        global.unblockUI();

    },

    pesquisarHistoricoFiltro: function () {

        this.historicoFiltroController = this.showView({
            region: {
                name: 'historicoFiltroControllerRegion',
                selector: '#pesquisar-historico-filtro-container'
            },
            controller: {
                type: PesquisarHistoricoFiltroController,
                args: {
                    model: this.model
                }
            }
        });
    },

    obterProdutoSelecionado: function () {
        return this.model;
    }

});