﻿var $boolSelecionarTodosProdutos = false;

var ProdutoItemView = Backbone.Marionette.ItemView.extend({
    template: '#template-lista-produtos-item',
    tagName: 'tr',
    className: 'clicavel',


    initialize: function (options) {
        this.app = options.app;
        this.parent = options.parent;
        this.adicionarProdutosCallback = options.adicionarProdutosCallback;        
    },

    events: {
        'click td.selecionavel ': 'selecionarProduto',
        'click a.icone-info': 'mostrarDetalhes'
    },

    ui: {
        checkbox: 'input:checkbox'
    },

    selecionarProduto: function (e) {

        var cor = $(e.target).parents('tr').css('background-color');      

        if (e.clientX != null) { // Click linha
            if (cor == 'rgb(255, 255, 255)' || cor == 'transparent' || cor == 'rgba(0, 0, 0, 0)') {
                $(e.target).parents('tr').css('background-color', '#FFFFCC');
                this.controller.model = this.model;
                this.parent.adicionarProduto(this.model);
            } else {
                $(e.target).parents('tr').css('background-color', '');
                this.parent.removerProduto(this.model);
            }
        } else { //Selecionar Todos
            if ($boolSelecionarTodosProdutos) {
                if (cor == 'rgb(255, 255, 255)' || cor == 'transparent' || cor == 'rgba(0, 0, 0, 0)') {                    
                    $(e.target).parents('tr').css('background-color', '#FFFFCC');
                    this.controller.model = this.model;
                    this.parent.adicionarProduto(this.model);
                }
            } else {                
                $(e.target).parents('tr').css('background-color', '');
                this.parent.removerProduto(this.model);
            }
        }

        this.produtoSelecionado();

    },

    produtoSelecionado: function (e) {

        if (this.parent.selecionados.length == 1) {

            this.menuConsultaProdutosController = new MenuConsultaProdutosController({
                controller: this.controller,
                model: this.parent.selecionados.models[0],
            });

            this.model.set('DescricaoProduto', this.model.get('Descricao'));
            this.model.set('CodigoProduto', this.model.get('Codigo'));

            this.menuConsultaProdutosController.show();
        } else {
            this.menuConsultaProdutosController = new MenuConsultaProdutosController({
                controller: this.controller,
                model: this.model
            });

            this.menuConsultaProdutosController.hide();
        }
    },

    mostrarDetalhes: function () {

        this.produtoInfoView = this.controller.showView({

            region: {
                name: 'produtoInfoViewRegion',
                selector: '#detalhes-produto-region'
            },
            view: {
                type: ProdutoInfoView,
                args: {
                    controller: this.controller,
                    model: this.model,
                    adicionarProdutosCallback: this.adicionarProdutosCallback
                }
            }
        });
    }
});

var ProdutoInfoView = Backbone.Marionette.ItemView.extend({
    template: '#template-lista-produtos-info',

    initialize: function (options) {
        this.app = options.app;
        this.parent = options.parent;
        this.controller = options.controller;
        this.adicionarProdutosCallback = options.adicionarProdutosCallback;

        this.model.set('DescricaoProduto', this.model.get('Descricao'));
        this.model.set('CodigoProduto', this.model.get('Codigo'));

        this.menuConsultaProdutosController = new MenuConsultaProdutosController({
            controller: this.options.controller,
            model: this.model
        });
    },

    onShow: function () {
        this.menuConsultaProdutosController.show();
        this.controller.obterParametrosInfo(false);
    },

    onDestroy: function () {
        this.menuConsultaProdutosController.hide();
    } 

});

var ProdutosView = Backbone.Marionette.CompositeView.extend({
    template: '#template-lista-produtos',
    childView: ProdutoItemView,
    childViewContainer: '#lista-produtos-container',

    initialize: function (options) {
        this.selecionados = new Backbone.Collection();
        this.app = options.app;
        this.parent = options.parent;
        this.adicionarProdutosCallback = typeof options.adicionarProdutosCallback != 'undefined' ? options.adicionarProdutosCallback : null;

        //Verifica se apenas um resultado foi recebido da consulta e insere automaticamente no orçamento
        if (options.collection.models.length == 1) {
            this.adicionarProduto(options.collection.models[0]);
            if (this.adicionarProdutosCallback) {
                this.adicionarProdutosCallback(this.selecionados.toJSON());
            }
        }       
    },

    events: {
        'click #adicionar-produtos': 'adicionarProdutos',
        'click #selecionar-todos-produtos': 'selecionarTodosProdutos'
        //'change #selecionar-todos-pesquisar-produtos': 'selecionarTodos'
    },

    buildChildView: function (item, itemView) {

        var view = new itemView({
            model: item,
            app: this.app,
            parent: this,
            adicionarProdutosCallback: this.adicionarProdutosCallback
        });

        if (this.controller) {
            view.controller = this.controller;
        }

        return view;
    },

    adicionarProduto: function (model) {
        this.selecionados.add(model);
    },

    removerProduto: function (model) {
        this.selecionados.remove(model);
    },

    adicionarProdutos: function () {

        if (this.selecionados.length == 0) {
            global.showErrorMessage('Por favor, selecione os produtos a serem adicionados.');
            return;
        }

        if (this.adicionarProdutosCallback) {
            this.adicionarProdutosCallback(this.selecionados.toJSON());
        }

        $('#menu-consulta-produtos').hide();
        $("#menu-sub-consulta-produtos").hide();

    },

    selecionarTodosProdutos: function (e) {

        if ($boolSelecionarTodosProdutos)
            $boolSelecionarTodosProdutos = false;
        else
            $boolSelecionarTodosProdutos = true;

        $('#lista-produtos-container td.selecionavel.codigo').trigger('click');
    }
});