﻿var ConfiguracoesFilialController = ControllerBase.extend({

    initialize: function() {
        this.atacharEventos();
        this.iniciarColorPicker();
        this.iniciarProgressBar();
        $('#filial').focus();
    },
    
    atacharEventos: function () {
        //$('.color-box').click($.proxy(this.iniciarColorPicker, this));
        $('#filial').change($.proxy(this.filialAlterada, this));
        $('#logo-filial').change($.proxy(this.logoAlterada, this));
        $('#salvar-configuracao-filial').click($.proxy(this.salvar, this));
    },

    iniciarColorPicker: function () {

        var self = this;

        $('.color-box').colpick({
            layout: 'hex',
            submit: 1,
            onSubmit: function (hsb, hex, rgb, el) {
                $(el).css('background-color', '#' + hex);
                $(el).colpickHide();
                self.cor = '#' + hex;
            }

        });

    },

    iniciarProgressBar: function () {

        var self = this;

        this.progressBar = $('#progressbar');
        this.progressLabel = $(".progress-label");

        this.dialog = $("#dialog").dialog({
            autoOpen: false,
            closeOnEscape: false,
            resizable: false,
            open: function () {

            },

        });

        this.progressBar.progressbar({
            value: false,
            change: function () {
                self.progressLabel.text("Progresso do upload: " + self.progressBar.progressbar("value") + "%");
            },
            complete: function () {
                $(".ui-dialog button").last().focus();
            }
        });
    },

    filialAlterada: function(e) {

        this.codigoFilial = $(e.target).val();

        var self = this;

        global.ajax({
            url: '/Configuracoes/ObterConfiguracaoFilial',
            type: 'post',
            data: {
                codigoFilial: self.codigoFilial
            },
            success: function (data) {
                if (data) {
                    self.carregar(data);
                } else {
                    self.limpar(false);
                }
                
            }
        });
    },

    logoAlterada: function(e) {
      
        this.file = e.target.files.length > 0 ? e.target.files[0] : null;

        if (!this.file) {
            return;
        }

        var fr = new FileReader();

        var self = this;

        fr.onload = function(_file) {
            $('#image-logo-filial').attr('src', fr.result);

            var image = new Image();
            image.src    = _file.target.result;              
            image.onload = function() {

                self.imageData = {
                    w: this.width,
                    h: this.height
                };
            }

        };

        fr.readAsDataURL(this.file);
    },
    
    carregar: function(data) {
        
        if (!data) {
            return;
        }

        this.codigoFilial = data.CodigoFilial;
        this.cor = data.Cor;
        this.logoUrl = data.LogoUrl;
        $('#image-logo-filial').attr('src', data.LogoUrl);

        if (data.Cor) {
            $('.color-box').css('background-color', data.Cor);
            $('.color-box').colpickSetColor(data.Cor, true);
        }

    },

    mostrarPercentual: function(percentual) {

        if (!this.dialog.dialog('isOpen')) {
            this.dialog.dialog('open');
        }


        this.progressBar.progressbar('value', global.formatNumber(percentual));
    },

    esconderPercentual: function() {
      
        if (typeof this.dialog != 'undefined') {
            this.dialog.dialog('close');
        }

    },

    validar: function() {

        var mensagem = '';

        if ($('#filial').val() == '') {
            mensagem = mensagem + '- O campo "Filial" é de preenchimento obrigatório.<br/>';
        }

        if ((typeof this.file == 'undefined' || !this.file) && (typeof this.logoUrl == 'undefined' || !this.logoUrl)) {
            mensagem = mensagem + '- O campo "Logo" é de preenchimento obrigatório.<br/>';
        }

        if (typeof this.file != 'undefined' && this.file) {
            var extension = this.file.name.split('.').pop();

            if (extension != 'png') {
                mensagem = mensagem + '- Favor inserir uma imagem no formato png.<br/>';
            }

            if (typeof this.imageData != 'undefined' && this.imageData && (this.imageData.w > 141 || this.imageData.h > 32 || this.file.size > 409600)) {
                mensagem = mensagem + '- A imagem selecionada está fora do padrão permitido:<br/> Largura máxima:141 pixels.<br/> Altura máxima: 32 pixels.<br/> Tamanho Máximo: 400 kb<br/>';
            }

        }

        if (typeof this.cor == 'undefined' || !this.cor) {
            mensagem = mensagem + '- O campo "Cor" é de preenchimento obrigatório.<br/>';
        }

        if (mensagem.length > 0) {
            global.showErrorMessage(mensagem);
            return false;
        }

        return true;

    },

    salvar: function() {

        if (!this.validar()) {
            return;
        }
        

        var self = this;

        var fd = new FormData();

        var mostrarPercentual = false;

        fd.append('codigoFilial', this.codigoFilial);

        if (typeof this.file != 'undefined' && this.file) {
            fd.append('logo', this.file);
            mostrarPercentual = true;
        }

        if (typeof this.cor != 'undefined' && this.cor) {
            fd.append('cor', this.cor);
        }


        global.ajax({
            url: '/Configuracoes/SalvarConfiguracaoFilial',
            type: 'post',
            data: fd,
            contentType: false,
            processData: false,

            xhr: function () {
                var xhr = new window.XMLHttpRequest();

                if (mostrarPercentual) {
                    xhr.upload.addEventListener("progress", function (evt) {
                        if (evt.lengthComputable) {
                            var percentComplete = (evt.loaded / evt.total) * 100;
                            self.mostrarPercentual(percentComplete);
                        }
                    }, false);
                    xhr.addEventListener("progress", function (evt) {
                        if (evt.lengthComputable) {
                            var percentComplete = (evt.loaded / evt.total) * 100;
                            self.mostrarPercentual(percentComplete);
                        }
                    }, false);
                }

                return xhr;
            },

            success: function (data) {
                
                self.esconderPercentual();
                global.showSuccessMessage('Configurações da filial alterada.');
                self.limpar();

            },
            error: function () {
                self.esconderPercentual();
            }
        });

    },

    limpar: function (limparFilial) {
        this.file = null;
        this.cor = null;
        this.logoUrl = null;

        if (typeof limparFilial == 'undefined' || limparFilial) {
            $('#filial').val('');
        }
        
        $('#image-logo-filial').attr('src', '');
        $('#logo-filial').val('');
        $('.color-box').css('background-color', '');


    }


});