﻿var ControllerBase = function (options) {
    _.extend(this, options);

    this.app = !this.app ? new Backbone.Marionette.Application() : this.app;
    this.rm = this.app._regionManager;
    this.breadcrumb = !this.breadcrumb ? new BreadCrumb() : this.breadcrumb;
    this.actionButtons = new Backbone.Collection();
    
    this.addRegion = function(region) {

        if (!region) {
            return null;
        }
        var regionInstance = this.getRegion(region.name);

        if (regionInstance) {
            return regionInstance;
        }

        regionInstance = this.rm.addRegion(region.name, region.selector);
        regionInstance.name = region.name;
        return regionInstance;
    };

    this.getRegion = function(name) {

        if (!name) {
            return null;
        }

        var region = this.app.getRegion(name);
        
        if (!region) {
            return null;
        }

        region.$el = $(region.options.el);
        return region;
    };

    this.resetRegion = function(name) {

        var region = this.getRegion(name);

        if (!region) {
            return;
        }

        region.reset();

    };

    this.clearRegion = function() {

        if (!this.region) {
            return;
        }

        this.region.$el.empty();

    };

    this.show = function(regionName) {

        var regionId;

        if (regionName) {

            var region = this.getRegion(regionName);

            if (!region) {
                return;
            }
            region.$el.show();
            regionId = region.el.options;

        } else {
            var $region = $('[region="main"]', $(this.container));
            $region.show();
            regionId = $region.attr('id');
        }

        this.breadcrumb.update(regionId);
        this.renderActionButtons();
    };

    this.addStack = function(item) {

        if (!this.stack) {
            this.stack = new Array();
        }

        this.stack.push(item);

    };

    this.showView = function(args) {

        var self = this;

        if (!args) {
            throw 'Argumentos não informados.';
        }

        var region = null;

        if (typeof args.region != 'undefined') {
            region = this.addRegion(args.region);
        } else {
            throw 'Region não definido';
        }

        this.currentRegion = region;

        var view = null;

        if (typeof args.view != 'undefined') {
            view = args.view;
        }

        var controller = null;

        if (typeof args.controller != 'undefined') {
            controller = args.controller;
        }

        if (typeof args.actionButtons != 'undefined') {
            this.addActionButtons(args.actionButtons);
        }

        this.renderActionButtons();
        
        if (view) {

            view.typeName = 'view';

            if (this.region) {
                $('[region]', $(this.region.options.el)).hide();
                $('[region]').has(region.$el).show();
            }

            var viewArgs = {
                app: this.app,
                parent: this,
                currentRegion: region
            };

            _.extend(viewArgs, view.args);

            view.instance = new view.type(viewArgs);
            view.instance.controller = this;

            if (typeof args.antesRenderizacaoCompleta != 'undefined') {
                args.antesRenderizacaoCompleta();
            }
            
            region.reset();
            region.show(view.instance);
            region.$el.show();

            if (typeof args.showBreadCrumb == 'undefined' || args.showBreadCrumb) {
                view.instance.breadcrumbItem = this.breadcrumb.add({
                    region: region,
                    view: view,
                    controller: {
                        instance: this
                    }
                });
            } else {
                this.breadcrumb.hide();
            }

            this.addStack(view);

            global.applyMasks();

            return view.instance;
        } 

        if (controller) {

            controller.typeName = 'controller';
            
            var controllerArgs = {
                app: this.app,
                parent: this,
                breadcrumb: this.breadcrumb,
                container: args.region.selector,
                region: region,
                currentRegion: region
            };

            _.extend(controllerArgs, controller.args);

            controller.instance = new controller.type(controllerArgs);
            ControllerBase.current = controller.instance;

            this.addStack(controller);

            if (typeof controller.instance.ajax != 'undefined') {
                var ajaxData = controller.instance.ajax();

                ajaxData.success = function (data) {
                    data = global.tratarRetorno(data);

                    if (data) {

                        if (self.region) {
                            $('[region]', $(self.region.options.el)).hide();
                            $('[region]').has(region.$el).show();
                        }

                        region.$el.empty();
                        region.$el.html(data);

                        var callback = $.proxy(self.controllerRenderizado, self, controller, region, args);
                        callback();
                    } 
                };

                global.ajax(ajaxData);

            } else {
                controller.instance.renderizar($.proxy(this.controllerRenderizado, this, controller, region, args));
            }
            
            return controller.instance;
        }

        return null;

    };

    this.controllerRenderizado = function (controller, region, args) {

        if (typeof args.antesRenderizacaoCompleta != 'undefined') {
            args.antesRenderizacaoCompleta();
        }

        region.$el.show();

        if (typeof args.showBreadCrumb == 'undefined' || args.showBreadCrumb) {

            if ($('[breadcrumb-start]', region.$el).length > 0) {
                controller.instance.breadcrumbItem = this.breadcrumb.add({
                    region: {
                        name: region.name,
                        $el: $('[breadcrumb-start]', region.$el),
                        options: region.options
                    },
                    controller: controller
                });
            } else {
                controller.instance.breadcrumbItem = this.breadcrumb.add({
                    region: region,
                    controller: controller
                });
            }
        } else {
            this.breadcrumb.hide();
        }

        if (typeof controller.instance.renderizado != 'undefined') {
            var callback = $.proxy(controller.instance.renderizado, controller.instance);
            callback();
        }

        global.applyMasks();

    };

    this.addActionButton = function(args, render) {

        if (!args || typeof args.text == 'undefined' || typeof args.click == 'undefined') {
            return null;
        }

        if (this.existActionButton(args)) {
            return this.getActionButton(args);
        }

        this.actionButtons.add(args);

        if (render) {
            this.renderActionButtons();
        }

        return this.getActionButton(args);
    };

    this.getActionButtonById = function(id) {
        return $('div[action-buttons] button#' + id);
    };

    this.getActionButton = function(args) {
        return $('div[action-buttons] button:contains("' + args.text + '")');
    };

    this.existActionButton = function(args) {
        return $('div[action-buttons] button:contains("' + args.text + '")').length > 0;
    };

    this.addActionButtons = function(actionButtons) {

        if (!actionButtons) {
            return;
        }

        var self = this;

        $.each(actionButtons, function() {
            self.addActionButton(this, false);
        });

        this.renderActionButtons();
    };

    this.renderActionButtons = function() {

        var el = $('div[action-buttons]');

        if (!el) {
            return;
        }

        el.empty();

        if (this.actionButtons.length == 0) {
            return;
        }
        var self = this;

        $.each(this.actionButtons.models, function() {

            if (!self.existActionButton(this.toJSON())) {
                var button = $('<button>', { id: this.get('id') });

                if (this.get('class')) {
                    button.addClass(this.get('class'));
                }

                button.html(this.get('text'));
                button.click($.proxy(this.get('click'), self));
                el.append(button);
            }
        });


    };

    this.hide = function() {

        //if (this.breadcrumbItem) {
        //    this.breadcrumb.remove(this.breadcrumbItem);
        //}

        var self = this;

        if (this.stack && this.stack.length > 0) {
            $.each(this.stack, function() {

                switch (this.typeName) {
                    case 'view':

                        if (typeof this.instance.breadcrumbItem != 'undefined' && this.instance.breadcrumbItem) {
                            self.breadcrumb.remove(this.instance.breadcrumbItem);
                        }

                        break;
                    case 'controller':

                        this.instance.hide();

                        break;
                }

            });
        }

        
        if (this.region) {
            
            this.region.$el = $(this.region.options.el);
            this.region.$el.hide();

            this.breadcrumb.update(this.region.name);

        } else {
            this.breadcrumb.removeLast();
        }

    };
    
    if (this.initialize) {
        this.initialize();
    }

};

var _extendControllerBase = function (protoProps, staticProps) {

    var parent = this;
    var child;

    if (protoProps && _.has(protoProps, 'constructor')) {
        child = protoProps.constructor;
    } else {
        child = function () { return parent.apply(this, arguments); };
    }

    _.extend(child, parent, staticProps);

    var Surrogate = function () { this.constructor = child; };
    Surrogate.prototype = parent.prototype;
    child.prototype = new Surrogate;

    if (protoProps) _.extend(child.prototype, protoProps);

    child.__super__ = parent.prototype;

    return child;
}


ControllerBase.extend = _extendControllerBase;


