﻿var $boolSelecionarTodosItensOrcamento = false;

var ItemOrcamentoController = ControllerBase.extend({

    initialize: function () {
        this.menuConsultaProdutosController = new MenuConsultaProdutosController({
            controller: this,
            obterModelCallback: $.proxy(this.obterItemSelecionado, this),
            adicionarProdutosCallback: $.proxy(this.adicionarProdutos, this),
        });
    },

    ajax: function () {

        return {
            url: '/Orcamento/_ItensOrcamento',
            type: 'get',
            cache: false,
            data: {
                identificadorOrcamento: this.model.get('IdentificadorOrcamento')
            }
        };
    },

    renderizado: function () {

        $('#pedido-cliente-item-menu').parent().addClass("inativo");
        $('#pedido-fornecedor-item-menu').parent().addClass("inativo");     

        if (typeof this.collection != 'undefined' && this.collection && this.collection.length > 0) {
            this.model.set('ItensOrcamento', new ItensOrcamento(this.collection));
        }

        var itensOrcamento = this.model.get('ItensOrcamento');

        this.itemOrcamentoView = this.showView({
            region: {
                name: 'itensOrcamentoRegion',
                selector: '#tabela-itens-orcamento-region',
            },
            view: {
                type: ItemOrcamentoView,
                args: {
                    collection: itensOrcamento,
                    orcamentoController: this.orcamentoController
                }
            }
        });

        this.atacharEventos();

        if (!itensOrcamento || itensOrcamento.length == 0) {
            this.incluirItens();
        }

        global.applyMasks();


    },

    atacharEventos: function () {
        $('#incluir-itens').click($.proxy(this.incluirItens, this));
        $('#comparar-itens').click($.proxy(this.compararItens, this));
        $('#excluir-itens').click($.proxy(this.excluirItens, this));
        $('#editar-itens').click($.proxy(this.editarItens, this));        
    },

    onhide: function (item) {

        var region = item.get('region');

        if (region && region.name == 'itemOrcamentoInfoViewRegion' && typeof this.menuConsultaProdutosController != 'undefined' && this.menuConsultaProdutosController) {
            this.habilitarMenuAcoesProdutoSelecionado();
        }
    },

    incluirItens: function () {

        this.removerSelecaoItens();

        $('#comparar-itens').prop('disabled', true);
        $('#editar-itens').prop('disabled', true);
        $('#excluir-itens').prop('disabled', true);

        this.pesquisarProdutosController = this.showView({
            region: {
                name: 'pesquisarProdutosRegion',
                selector: '#pesquisar-produtos-container'
            },
            controller: {
                type: PesquisarProdutosController,
                args: {
                    model: this.model,
                    adicionarProdutosCallback: $.proxy(this.adicionarProdutos, this)
                }
            }

        });
    },

    adicionarProdutos: function (produtos) {

        this.show();        

        if (this.pesquisarProdutosController)
            this.pesquisarProdutosController.hide();

        if (this.menuConsultaProdutosController.agregadosController) {
            this.menuConsultaProdutosController.agregadosController.hide();
        }

        if (this.menuConsultaProdutosController.similaresController) {
            this.menuConsultaProdutosController.similaresController.hide();
        }

        if (!produtos || produtos.length == 0) {
            return;
        }

        this.model.adicionarItens(produtos);

        this.removerSelecaoItens();

        this.habilitarBotoes();
    },

    editarItem: function (item) {

        if (!item) {
            return;
        }

        this.editarItemController = this.showView({
            region: {
                name: 'editarItemOrcamentoControllerRegion',
                selector: '#editar-item-orcamento-container'
            },
            controller: {
                type: EditarItemOrcamentoController,
                args: {
                    model: item,
                    finalizarEdicaoItemCallback: $.proxy(this.finalizarEdicaoItem, this),
                    cancelarEdicaoItemCallback: $.proxy(this.cancelarEdicaoItem, this)
                }
            }
        });

    },

    finalizarEdicaoItem: function () {
        this.show();
        this.editarItemController.hide();
        this.editarItemController.clearRegion();
    },

    habilitarBotoes: function () {
        var selecionados = this.model.get('ItensOrcamento').where({ selecionado: true });
        var habilitarComparar = selecionados.length > 1;
        var habilitarEditarExcluir = selecionados.length > 0;

        $('#comparar-itens').prop('disabled', !habilitarComparar);
        $('#editar-itens').prop('disabled', !habilitarEditarExcluir);
        $('#excluir-itens').prop('disabled', !habilitarEditarExcluir);


        this.habilitarMenuAcoesProdutoSelecionado();
    },

    habilitarMenuAcoesProdutoSelecionado: function () {

        var selecionados = this.model.get('ItensOrcamento').where({ selecionado: true });
        var habilitarAcoesProduto = selecionados.length == 1;

        if (habilitarAcoesProduto) {
            this.menuConsultaProdutosController.show();
        } else {
            this.menuConsultaProdutosController.hide();
        }

    },

    obterItemSelecionado: function () {
        var selecionados = this.model.get('ItensOrcamento').where({ selecionado: true });
        return selecionados.length > 0 ? selecionados[0] : null;
    },

    compararItens: function () {

        var itens = this.model.get('ItensOrcamento').toJSON();
        itens = global.where(itens, { selecionado: true });

        if (itens.length == 0) {
            global.showErrorMessage('Selecione pelo menos 2 itens.');
            return;
        }

        this.compararProdutosController = this.showView({
            region: {
                name: 'compararProdutosControllerRegion',
                selector: '#comparar-produtos-region'
            },
            controller: {
                type: CompararProdutosController,
                args: {
                    collection: itens
                }
            }
        });
    },

    itensSelecionados: function () {
        return this.model.get('ItensOrcamento').where({ selecionado: true });
    },

    excluirItens: function () {

        var itens = this.model.get('ItensOrcamento').toJSON();
        itens = global.where(itens, { selecionado: true });

        if (itens.length == 0) {
            global.showErrorMessage('Selecione os itens a serem excluídos.');
            return;
        }

        var itensSelecionados = this.itensSelecionados();

        var self = this;

        global.ajax({
            url: '/Orcamento/ExcluirItens',
            type: "post",
            contentType: 'application/json',
            data: JSON.stringify({
                identificadorOrcamento: this.model.get('IdentificadorOrcamento'),
                itens: itens
            }),
            success: function (data) {

                data = global.tratarRetorno(data);

                if (data) {
                    self.model.set('ValorTotal', data.ValorTotal);
                    self.model.set('ValorTotalMercadorias', data.ValorTotalMercadorias);
                    global.showSuccessMessage('Produto(s) excluído(s) com sucesso.');
                    self.model.get('ItensOrcamento').remove(itensSelecionados);
                    self.habilitarBotoes();
                }
            }
        });
    },

    editarItens: function () {

        var itensSelecionados = this.itensSelecionados();

        if (itensSelecionados.length == 0) {
            global.showErrorMessage('Selecione os itens a serem editados.');
            return;
        }

        this.editarItensOrcamentoController = this.showView({
            region: {
                name: 'editarItensOrcamentoControllerRegion',
                selector: '#editar-itens-orcamento-container'
            },
            controller: {
                type: EditarItensOrcamentoController,
                args: {
                    collection: new Backbone.Collection(itensSelecionados),
                    finalizarEdicaoItens: $.proxy(this.finalizarEdicaoItens, this)
                }
            }
        });

    },

    finalizarEdicaoItens: function () {
        this.show();
        this.editarItensOrcamentoController.hide();
        this.editarItensOrcamentoController.clearRegion();
        this.removerSelecaoItens();
        this.itemOrcamentoView.removerSelecao();
        this.habilitarBotoes();
    },

    removerSelecaoItens: function () {

        $('#tabela-itens-orcamento-region td.selecionavel').parents('tr').css('background-color', '');

        this.model.get('ItensOrcamento').each(function (model) {
            model.set('selecionado', false);
        });

    },

    cancelarEdicaoItem: function () {

    },

    obterParametrosInfo: function (async) {
        this.obterParametro('EXIBIR_QUANTIDADE_ESTOQUE_CONSULTA_PRODUTOS', async);
        this.obterParametro('EXIBIR_PRECO_COMISSAO_NA_CONSULTA_PRODUTOS', async);
        this.obterParametro('EXIBIR_QUANTIDADE_MINIMA_VENDA_CONSULTA_PRODUTOS', async);
    },

    obterParametro: function (nomeInterno, async) {

        var pesquisa = {
            nomeInterno: nomeInterno
        };

        var self = this;

        global.ajax({
            url: '/Usuario/_ObterParametro',
            type: "post",
            contentType: 'application/json',
            data: JSON.stringify(pesquisa),
            async: async,
            success: function (data) {
                self.esconderDiv(pesquisa.nomeInterno, data);
            }
        });
    },

    esconderDiv: function (nomeInterno, valorParametro) {

        switch (nomeInterno) {
            case 'EXIBIR_PRECO_COMISSAO_NA_CONSULTA_PRODUTOS':
                if (valorParametro != 'S')
                    $('#detalhe-item-orcamento-region').find('#linha-comissao-venda').remove();
                else
                    $('#detalhe-item-orcamento-region').find('#linha-comissao-venda').show();
                break;
            case 'EXIBIR_QUANTIDADE_ESTOQUE_CONSULTA_PRODUTOS':
                if (valorParametro != 'S')
                    $('#detalhe-item-orcamento-region').find('#linha-quantidade-disponivel').remove();
                else
                    $('#detalhe-item-orcamento-region').find('#linha-quantidade-disponivel').show();
                break;
            case 'EXIBIR_QUANTIDADE_MINIMA_VENDA_CONSULTA_PRODUTOS':
                if (valorParametro != 'S')
                    $('#detalhe-item-orcamento-region').find('#linha-quantidade-minima-venda').remove();
                else
                    $('#detalhe-item-orcamento-region').find('#linha-quantidade-minima-venda').show();
                break;
        }
    }


});