﻿var OrcamentoController = ControllerBase.extend({

    initialize: function () {
        this.atacharEventos();
    },

    setModel: function(orcamento) {
      
        if (!orcamento) {
            return;
        }

        this.model = new Orcamento(orcamento);
        this.model.on('change:ValorTotalMercadorias', this.atualizarTotais, this);
        this.model.on('change:ValorTotal', this.atualizarTotais, this);
        this.atualizarTotais();
    },

    iniciar: function(orcamento) {

        this.setModel(orcamento);


        $('[item-menu]').parent().removeClass('ativo');
        $('[item-menu="item-venda"]').parent().addClass('ativo');

        this.renderizarViewItemVenda();

    },

    atacharEventos: function () {

        $('[item-menu]').click($.proxy(this.itemMenuSelecionado, this));
        //$(document).keydown($.proxy(this.tratarAtualizacaoPagina, this));
        $(window).on('beforeunload', $.proxy(this.tratarVoltarPagina, this));
        $('body').on('contextmenu', $.proxy(this.desligarMenu, this));
    },

    desligarMenu: function() {
        return false;
    },

    tratarVoltarPagina: function () {

        var permitirSairView = $(window).attr('permitirSairView');

        if (permitirSairView != undefined && permitirSairView) {
            return;
        }

        if (this.model) {
            return 'Atenção, o orçamento iniciado será perdido, deseja continuar?';
        }
    },

    tratarAtualizacaoPagina: function(e) {
      
        if (!((e.which || e.keyCode) == 116)) {
            return;
        }

        if (typeof this.model == 'undefined' || !this.model) {
            return;
        }

        if (!global.confirm('Atenção, o orçamento iniciado será perdido, deseja continuar?')) {
            e.preventDefault();
        }
    },

    mostrarAsideDireita: function(e) {
      
        if ($(e.target).hasClass('ativo')) {
            $(e.target).removeClass('ativo');
            $('aside').hide();
            $('aside').addClass('none');
            
        } else {
            $(e.target).addClass('ativo');
            $('aside').show();
            $('aside').removeClass('none');
        }

        

    },
    
    itemMenuSelecionado: function (e) {

        $('[item-menu]').parent().removeClass('ativo');
        $(e.target).parent().addClass('ativo');

        var itemMenu = $(e.target).attr('item-menu');

        switch (itemMenu) {
            case 'cliente':
                this.renderizarViewCliente();
                break;
            case 'forma-pagamento':
                this.renderizarViewFormaPagamento();
                break;
            case 'item-venda':
                this.renderizarViewItemVenda();
                break;
            case 'finalizar-orcamento':
                this.renderizarViewFinalizarOrcamento();
                break;
        }
    },

    
    esconderContainers: function() {
        $('[container]').hide();
    },

    renderizarViewCliente: function () {

        this.esconderContainers();

        this.pesquisarClientesController = this.showView({
            region: {
                name: 'pesquisarClientesRegion',
                selector: '#pesquisar-clientes-region'
            },
            controller: {
                type: PesquisarClientesController,
                args: {
                    model: this.model,
                    orcamentoController: this
                }
            }
        });
        
    },

    selecionarFormaPagamentoCallback: function (cliente) {

        if (cliente) {
            this.model.set('FormaPagamento', cliente.get('Codigo'));
        }
    },

    limparFormaPagamentoCallback: function () {
        this.model.unset('CodigoCliente');
    },

    renderizarViewFormaPagamento: function () {
        
        this.esconderContainers();

        this.formaPagamentoController = this.showView({
            region: {
                name: 'formaPagamentoControllerRegion',
                selector: '#forma-pagamento-orcamento-region'
            },
            controller: {
                type: FormaPagamentoController,
                args: {
                    model: this.model,
                    orcamentoController: this
                }
            }
        });

        this.mostrarValoresOrcamento();

    },
    
    renderizarViewItemVenda: function () {

        this.esconderContainers();

        this.itemOrcamentoController = this.showView({
            region: {
                name: 'itemOrcamentoRegion',
                selector: '#itens-orcamento-region'
            },
            controller: {
                type: ItemOrcamentoController,
                args: {
                    model: this.model,
                    orcamentoController: this
                }
            }
        });

        this.mostrarValoresOrcamento();
        
    },

    renderizarViewFinalizarOrcamento: function () {

        this.esconderContainers();

        this.finalizarOrcamentoController = this.showView({
            region: {
                name: 'finalizarOrcamentoControllerRegion',
                selector: '#finalizar-orcamento-region'
            },
            controller: {
                type: FinalizarOrcamentoController,
                args: {
                    model: this.model
                }
            }
        });

        this.mostrarValoresOrcamento();
    },

    mostrarValoresOrcamento: function () {
        $("#menu-consulta-produtos").hide();
        $("#menu-sub-consulta-produtos").hide();
        AsideDireita.show('valores-orcamento');
    },



    atualizarTotais: function() {
        $('#valor-total-mercadorias-orcamento').html(global.formatMoney(this.model.get('ValorTotalMercadorias')));
        $('#valor-total-orcamento').html(global.formatMoney(this.model.get('ValorTotal')));
    }
    
});