﻿var PesquisarClientesController = ControllerBase.extend({
    form: '#form-pesquisar-clientes',

    ajax: function() {
        return {
            url: '/Cliente/_Pesquisar',
            type: 'get',
            cache: false
        };
    },

    renderizado: function() {

        if (this.model.get('Cliente')) {
            this.mostrarDetalheCliente(false);
        } else {
            $('#form-pesquisa-clientes-container').show();
        }

        $('#Nome').focus();

        $('#menu-consulta-produtos').hide();
        $("#menu-sub-consulta-produtos").hide();

        this.atacharEventos();

        this.configurarForm();

        global.applyConditionalMask({
            triggerElement: 'input[name="CpfCnpj"]',
            triggerEvent: 'keydown',
            initialMask: 'cpf',
            options: {
                removeMaskOnSubmit: true
            },
            masks: [
                {
                    name: 'cpf',
                    mask: '999.999.999-99',
                    condition: function(e) {
                        return $('input[name="CpfCnpj"]').inputmask('unmaskedvalue').length < 11;
                    }
                },
                {
                    name: 'cnpj',
                    mask: '99.999.999/9999-99',
                    condition: function(e) {
                        return $('input[name="CpfCnpj"]').inputmask('unmaskedvalue').length >= 11;
                    }
                }
            ]
        });
        
    },
    
    atacharEventos: function() {

        this.addActionButton({
            text: 'Limpar',
            'class': 'icone-excluir separador',
            click: $.proxy(function() {

               
                if (typeof this.currentRegion == 'undefined' || typeof this.currentRegion.options == 'undefined') {
                    return;
                }

                switch (this.currentRegion.options.el) {
                    case '#detalhe-cliente-region':
                        this.limparCliente();
                        
                        break;
                    case '#pesquisar-clientes-region':
                        $(this.form).resetForm();
                        break;
                    case '#clientes-region':
                        $(this.form).resetForm();

                        if (this.clienteView) {
                            var region = this.getRegion('clientesRegion');

                            if (region) {
                                region.reset();
                            }
                        }

                        break;
                }
                
            }, this)
        }, true);

        $('#pesquisar-clientes').unbind();
        $('#pesquisar-clientes').click($.proxy(this.pesquisarClick, this));

        $("#ficha-crediario-item-menu").unbind();
        $("#ficha-crediario-item-menu").click($.proxy(this.pesquisarFichaCrediario, this));
        
        $("#ficha-financeira-item-menu").unbind();
        $("#ficha-financeira-item-menu").click($.proxy(this.pesquisarFichaFinanceira, this));

        $("#credito-item-menu").unbind();
        $("#credito-item-menu").click($.proxy(this.pesquisarCredito, this));

        $("#limite-credito-item-menu").unbind();
        $("#limite-credito-item-menu").click($.proxy(this.pesquisarLimiteCredito, this));

        $("#orcamento-aberto-item-menu").unbind();
        $("#orcamento-aberto-item-menu").click($.proxy(this.pesquisarOrcamentosEmAberto, this));

        $("#acompanhamento-item-menu").unbind();
        $("#acompanhamento-item-menu").click($.proxy(this.pesquisarAcompanhamentos, this));

        $("#documento-aberto-item-menu").unbind();
        $("#documento-aberto-item-menu").click($.proxy(this.pesquisarDocumentosEmAberto, this));
    },

    limparCliente: function() {
        this.model.unset('Cliente');
        this.model.unset('CodigoCliente');
        this.model.set('CodigoCliente', 0); // Valor padrão de inicialização do Cliente.
        this.breadcrumb.cancel();
        this.OcultarMenuCliente();
        this.parent.renderizarViewCliente();
        
    },

    configurarForm: function () {

        var self = this;

        this.validationOptions = {
            errorClass: 'obrigatorio',
            onkeyup: false,
            errorPlacement: function (error, element) {
                return true;
            },
            focusInvalid: false,
            invalidHandler: function (event, validator) {

                var errors = validator.numberOfInvalids();

                if (errors) {
                    var messages = new Array();

                    $.each(validator.errorList, function () {
                        messages.push(this.message);
                    });

                    global.showErrorMessage(messages);

                    return false;
                }

            }
        };

        $(this.form).validate(this.validationOptions);

    },

    pesquisar: function (e, numeroPagina) {

        if (e) {
            e.preventDefault();
        }

        var formdata = global.convertFormToJSON({ selector: this.form });
        formdata.TamanhoPagina = this.pesquisa ? this.pesquisa.PageSize : 20;
        formdata.NumeroPagina = this.pesquisa ? this.pesquisa.ActualPage : 1;

        if (numeroPagina)
            formdata.NumeroPagina = numeroPagina;

        var self = this;

        global.ajax({
            url: '/Cliente/Pesquisar',
            type: "post",
            contentType: 'application/json',
            data: JSON.stringify(formdata),
            error: function (data) {
                
                global.showErrorMessage('Ocorreu um problema com a requisição, por favor tente novamente.');
            },
            success: function (data) {


                data = global.tratarRetorno(data);
                self.carregar(data);

                if (data == null)
                    $("#clientes-region").hide();
            }
        });
        
        

    },

    paginar: function (e) {
        this.pesquisa.ActualPage = e.page;
        this.pesquisar();
    },
    
    pesquisarClick: function (e) {

        if (e) {
            e.preventDefault();
        }

        this.pesquisar(e, 1); // Pesquisa sempre a primeira página.
    },

    carregar: function (data) {

        if (!data) {
            global.unblockUI();

            return;
        }

        this.pesquisa = data;

        $('#clientes-region').removeClass('none').addClass('separador');

        this.clienteView = this.showView({
            region: {
                name: 'clientesRegion',
                selector: '#clientes-region',
            },
            view: {
                type: ClienteView,
                args: {
                    collection: new Clientes(data.Entities),
                    clienteSelecionadoCallbackView: $.proxy(this.clienteSelecionadoCallbackView, this),
                    clienteLimparCallback: this.limparClienteCallback
                }
            }
        });

        this.paginador = new Paginator({
            container: '#page-cliente-container',
            data: data,
            pageClickCallback: $.proxy(this.paginar, this)
        });

        global.unblockUI();
        

        
    },
    
    mostrarDetalheCliente: function(showBreadCrumb) {

        var cliente = this.model.get('Cliente');

        if (!cliente) {
            return;
        }

        $('#detalhe-cliente-region').attr('breadcrumb', cliente.get('Nome'));

        this.detalheClienteView = this.showView({
            showBreadCrumb: showBreadCrumb,
            region: {
                name: 'detalheClienteRegion',
                selector: '#detalhe-cliente-region',
            },
            view: {
                type: DetalheClienteView,
                args: {
                    model: cliente
                },
                showBreadcrumbCancelButton: false
            }
        });


        //$('#breadcrumb-cancelar').hide();
        
        $('#form-pesquisa-clientes-container').hide();

        this.mostrarMenuCliente();

    },

    clienteSelecionadoCallbackView: function (cliente) {

        if (!cliente) {
            return;
        }

        this.model.set('Cliente', cliente);
        this.model.set('CodigoCliente', cliente.get('Codigo'));
        this.mostrarDetalheCliente();
    },

    pesquisarFichaCrediario: function () {

        var cliente = this.model.get('Cliente');
        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            CodigoCliente: this.model.get('CodigoCliente'),
            TipoPessoa: cliente.get('TipoPessoa')
        };

        this.fichaCrediarioController = this.showView({
            region: {
                name: 'fichaCrediarioRegion',
                selector: '#ficha-crediario-container'
            },
            controller: {
                type: FichaCrediarioController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });
    },

   

    pesquisarCredito: function () {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            CodigoCliente: this.model.get('CodigoCliente')
        };

        this.creditoController = this.showView({
            region: {
                name: 'creditoRegion',
                selector: '#credito-container'
            },
            controller: {
                type: CreditoController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });
    },

   
    pesquisarLimiteCredito: function () {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            CodigoCliente: this.model.get('CodigoCliente')
        };

        this.limiteCreditoController = this.showView({
            region: {
                name: 'limiteCreditoRegion',
                selector: '#limite-credito-container'
            },
            controller: {
                type: LimiteCreditoController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });
        
    },
    
    pesquisarFichaFinanceira: function () {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 1,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 0,
            CodigoCliente: this.model.get('CodigoCliente')
        };

        this.fichaFinanceiraController = this.showView({
            region: {
                name: 'fichaFinanceiraRegion',
                selector: '#ficha-financeira-container'
            },
            controller: {
                type: FichaFinanceiraController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });

    },


    pesquisarOrcamentosEmAberto: function() {

        var pesquisaOrcamentoAberto = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 1000,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            Codigo: this.model.get('CodigoCliente')
        };

        this.orcamentoAbertoController = this.showView({
            region: {
                name: 'orcamentoAbertoControllerRegion',
                selector: '#orcamento-aberto-container'
            },
            controller: {
                type: OrcamentoAbertoController,
                args: {
                    pesquisaOrcamentoAberto: pesquisaOrcamentoAberto
                }
            }
        });
    },       

    pesquisarAcompanhamentos: function() {

        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            CodigoCliente: this.model.get('CodigoCliente')
        };

        this.acompanhamentoController = this.showView({
            region: {
                name: 'acompanhamentoRegion',
                selector: '#acompanhamento-container'
            },
            controller: {
                type: AcompanhamentoController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });
    },

    pesquisarDocumentosEmAberto: function () {


        var pesquisa = {
            TamanhoPagina: this.pesquisa ? this.pesquisa.PageSize : 20,
            NumeroPagina: this.pesquisa ? this.pesquisa.ActualPage : 1,
            CodigoCliente: this.model.get('CodigoCliente'),
            TipoConsulta: "EA"
        };

        this.documentoAbertoController = this.showView({
            region: {
                name: 'documentoAbertoRegion',
                selector: '#documento-aberto-container'
            },
            controller: {
                type: DocumentoAbertoController,
                args: {
                    pesquisa: pesquisa
                }
            }
        });

    },

    mostrarMenuCliente: function () {
        AsideDireita.show('cliente-pesquisa');
    },
    
    OcultarMenuCliente: function () {
        AsideDireita.show('valores-orcamento');
    }

});